@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------------
    libconfig - A library for processing structured configuration files
-   Copyright (C) 2005-2018  Mark A Lindner
+   Copyright (C) 2005-2020  Mark A Lindner
 
    This file is part of libconfig.
 
@@ -34,8 +34,10 @@ typedef struct
   size_t capacity;
 } strvec_t;
 
-void strvec_append(strvec_t *vec, const char *s);
+extern void libconfig_strvec_append(strvec_t *vec, const char *s);
 
-const char **strvec_release(strvec_t *vec);
+extern const char **libconfig_strvec_release(strvec_t *vec);
+
+extern void libconfig_strvec_delete(const char * const *vec);
 
 #endif /* __libconfig_strvec_h */
